=======
History
=======

0.1.2 (2019-02-06)
-------------------

* 'mtdeconv': If response is available, files needed for the computation of the response are not loaded.

0.1.1 (2019-02-06)
------------------

* First release on PyPI.

0.1.0 (2019-02-06)
------------------

* Making repository public on Github
